##
##  imaputils.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2008 OpenPKG Foundation e.V. <http://openpkg.net/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         imaputils
Summary:      Generic IMAP Utilities
URL:          http://www.washington.edu/imap/
Vendor:       University of Washington
Packager:     OpenPKG Foundation e.V.
Distribution: OpenPKG Community
Class:        PLUS
Group:        Mail
License:      University of Washington's Free-Fork License
Version:      2002
Release:      20080101

#   list of sources
Source0:      ftp://ftp.openpkg.org/sources/CPY/VERSIONED/imaputils/imap-utils-%{version}.tar.Z
Patch0:       imaputils.patch

#   build information
Prefix:       %{l_prefix}
BuildRoot:    %{l_buildroot}
BuildPreReq:  OpenPKG, openpkg >= 20040130, imap, openssl
PreReq:       OpenPKG, openpkg >= 20040130
AutoReq:      no
AutoReqProv:  no

%description
    The IMAP utilities is a collection of binaries useful in
    administrating a IMAP server. Although some work best with the
    University of Washington IMAP server, many of the utilites are
    generic and useful with any IMAP server. The utilities include
    chkmail, dmail, icat, ifrom, imapcopy, imapxfer, mbxcopy, mbxcreat,
    mbxcvt, mlock, and tmail.

%track
    prog imaputils = {
        version   = %{version}
        url       = ftp://ftp.openpkg.org/sources/CPY/VERSIONED/imaputils/
        regex     = imap-utils-(__VER__)\.tar\.Z
    }

%prep
    %setup -q -c
    %patch -p0

%build
    CC="%{l_cc}"
    CFLAGS="%{l_cflags -O}"
    CPPFLAGS="%{l_cppflags imap}"
    LDFLAGS="%{l_ldflags}"
    LIBS="-limap -lssl -lcrypto"
    case "%{l_platform -t}" in
        *-sunos*    ) LIBS="$LIBS -lnsl -lsocket" ;;
        *-linux*    ) LIBS="$LIBS -lcrypt" ;;
        *-freebsd*  ) LIBS="$LIBS -lcrypt" ;;
        *-netbsd*   ) LIBS="$LIBS -lcrypt" ;;
        * ) echo "Sorry, platform %{l_platform -t} not supported" 2>&1; exit 1 ;;
    esac
    for util in *; do
        ( cd $util
          $CC -c $CPPFLAGS `echo *.c`
          $CC -o $util `echo *.o` $LDFLAGS $LIBS
        ) || exit $?
    done

%install
    rm -rf $RPM_BUILD_ROOT
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin \
        $RPM_BUILD_ROOT%{l_prefix}/man/man1
    for util in *; do
        ( cd $util
          %{l_shtool} install -c -s -m 755 \
              $util $RPM_BUILD_ROOT%{l_prefix}/bin/
          if [ -f *.1 ]; then
              %{l_shtool} install -c -m 644 \
                  *.1 $RPM_BUILD_ROOT%{l_prefix}/man/man1/
          fi
        ) || exit $?
    done
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean
    rm -rf $RPM_BUILD_ROOT

